#!/usr/bin/env python
# -*- coding: utf_8 -*-

import copy
import time
import types
import json
import logging
import traceback
from threading import Thread

from werkzeug.security import check_password_hash
from model import fullStackDB
from model.user import User
from fullstack.login import Auth
from fullstack.response import ResponseCode
from utils import md5_salt

logger = logging.getLogger("LoginManager")


class LoginManager(object):
    '''
     用户管理的单例类
    '''

    def __init__(self):
        super(LoginManager, self).__init__()
        # Thread(target=self.dashboard).start()

    def login(self, data):
        '''
        用户登录
        :param data:登录的用户信息json如 { "account": "xx", "password": "xx" }
        :return ret: dict类型的登录相关信息
        '''

        try:
            # 判断用户名是否存在
            result = User.get(account=data.get("account"))
            if not result:
                return False, ResponseCode.NO_DATA_FOUND

            # 判断密码是否正确
            result = User.get(account=data.get("account"), password=md5_salt(data.get("password")))
            if not result:
                return False, ResponseCode.PASSWORD_ERROR

            # 判断用户是否禁用
            if result.is_delete:
                return False, ResponseCode.ACCOUNT_DISABLED

            # 返回token
            token = Auth.encode_auth_token(result.id, result.username) # 生成 token
            # setattr(result, 'token', token)
            return { 'token': token, 'id': result.id, 'username': result.username }, ResponseCode.OK
        except Exception as e:
            traceback.print_exc()
            logger.error(str(e))
            return False, str(e)

    def logout(self):
        '''
        用户登出
        '''
        try:
            return True, "User logout success."
        except Exception as e:
            traceback.print_exc()
            logger.error(str(e))
            return False, str(e)

    def register(self, data):
        '''
        用户注册
        '''
        try:
            # 判断账号是否存在
            result = User.get(account=data.get("account"))
            if result:
                return False, "User already exists"

            result = fullStackDB.add(User, **data)
            return result, "User registration is {}.".format("success" if result else "fail")

        except Exception as e:
            traceback.print_exc()
            logger.error(str(e))
            return False, str(e)

loginManager = LoginManager()
