#!/usr/bin/env python
# -*- coding: utf_8 -*-

import copy
import time
import types
import json
import logging
import traceback
from datetime import datetime
from pony.orm import *
from flask import request
from model import fullStackDB
from model.summary import Summary
from model.user import User
from utils import sql_filter

logger = logging.getLogger("SummaryManager")

class SummaryManager(object):
    def __init__(self):
        super(SummaryManager, self).__init__()

    def add(self, data):
        # 判断角色名是否存在
        result = Summary.get(name=data.get("name"))
        if result:
            return False, "summary name has been exists."

        editor = User.get(id=request.current_user.get("id"))
        if not editor:
            return False, "current user is not exists"

        data.update({
            'create_by': editor,
            'create_at': datetime.now(),
            'update_by': editor,
            'update_at': datetime.now(),
        })

        result = fullStackDB.add(Summary, **data)
        return result, "add summary {}.".format("success" if result else "fail")

    def delete(self, uuid):
        editor = User.get(id=request.current_user.get("id"))
        if not editor:
            return False, "current user is not exists"

        result = fullStackDB.update(Summary, { 'uuid': uuid }, is_delete=True, delete_at=datetime.now(), delete_by=editor)
        return result, "delete summary {}.".format("success" if result else "fail")

    def get(self, data):
        result = Summary.get(**data)
        if result:
            result = result.to_dict(only=["uuid", "name", "create_at", "update_at"])
        return result, "get summary {}.".format("success" if result else "no data")

    def getList(self, data):
        if not data or len(data) <= 0:
            return False, 0, "parameters can not be null."

        temp = copy.deepcopy(data)
        if 'pagenum' in temp:
            temp.pop('pagenum')
        if 'pagesize' in temp:
            temp.pop('pagesize')
        if 'scope_type' in temp:
            temp.pop('scope_type')
        if 'props' in temp:
            temp.pop('props')
        temp.setdefault("is_delete", False)

        if "scope_type" in data and data.get("scope_type") == "list":
            result = Summary.select().where(**temp).order_by(desc(Summary.create_at))
            temp = []
            fields = ["uuid", "name"]
            if "props" in data and isinstance(data.get("props"), list):
                fields = data.get("props")
            for item in result:
                temp.append(item.to_dict(only=fields))
            return temp, len(temp), "get summary {}.".format("success" if temp else "fail")

        result = fullStackDB.pagination(Summary, Summary.create_at, pagenum=data.get("pagenum", 1), pagesize=data.get("pagesize", 10), **temp)
        count = fullStackDB.count(Summary, **temp)

        if result and len(result):
            temp = []
            for item in result:
                t = item.to_dict(with_collections=True, related_objects=True)
                t.update({ "create_at": item.create_at.strftime("%Y-%m-%d %H:%M:%S") })
                t.update({ "update_at": item.update_at.strftime("%Y-%m-%d %H:%M:%S") })
                t.update({ "create_by": item.create_by.to_dict(only=["uuid", "username"]) })
                t.update({ "update_by": item.update_by.to_dict(only=["uuid", "username"]) })
                temp.append(t)
            result = temp

        return result, count, "get summary {}.".format("success" if result else "no data")

    def update(self, uuid, data):
        # 当参数为空时，直接返回错误
        if len(data) <= 0 or (len(data.keys()) == 1 and "id" in data):
            return False, "parameters can not be null."

        # 查询请求者是否存在
        editor = User.get(id=request.current_user.get("id"))
        if not editor:
            return False, "current user is not exists"

        result = fullStackDB.update(Summary, { 'uuid': uuid }, update_at=datetime.now(), update_by=editor, **data)
        return result, "update summary {}.".format("success" if result else "fail")

summaryManager = SummaryManager()
